# mini_lemmatizer

A lightweight lemmatization tool built with NLTK.

### Example
```python
from mini_lemmatizer import MiniLemmatizer
lemm = MiniLemmatizer()
print(lemm.lemmatize_sentence("The cats are chasing mice"))
